<template>
    <div class="report-overview">
        <div class="search-box">
            项目分类：
            <dict-select :popperClass="`big-search-popper`" dictCode="sgyp-xmfl" :hasDefaultOption="true" clearable
                v-model="projectCategory" style="width: 350px;" placeholder="请选择所项目分类" @input="() => getData()" />
        </div>
        <el-table height="calc(100% - 50px)" :element-loading-background="loadingColor" v-loading="loading"
            align="center" :data="tableData" id="table-bigger-detail" class="dialog_table"
            :header-cell-style="{ 'text-align': 'center' }" ref="myTable">
            <el-table-column prop="orderNo" label="序号" width="60" align="center">
            </el-table-column>
            <el-table-column prop="projectName" label="项目名称" align="left" min-width="190">
            </el-table-column>
            <el-table-column prop="unitName" label="主责单位" width="140" align="center">
            </el-table-column>
            <el-table-column prop="groupName" label="专项小组" width="160" align="center">
                <!-- <template v-slot="{ row }">
                    {{ row.groupName.slice(0, row.groupName.length - 6) }}
                </template> -->
            </el-table-column>
            <el-table-column prop="" :label="`形成\n调研报告`" align="center" width="160">
                <template v-slot="{ row }">
                    <div v-if="row.produceReport" :style="`${setStyle(row.produceReport)}`">
                        {{ getDictName('zbqdyp_zt', row.produceReport) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`形成\n改革方案初稿`" align="center" width="160">
                <template v-slot="{ row }">
                    <div v-if="row.formScheme" :style="`${setStyle(row.formScheme)}`">
                        {{ getDictName('zbqdyp_zt', row.formScheme) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`提出调整准备\n启动一批的申请`" align="center" width="150">
                <template v-slot="{ row }">
                    <div v-if="row.requestReadyToStart" :style="`${setStyle(row.requestReadyToStart)}`">
                        <!-- {{row.requestReadyToStart}} -->
                        {{ getDictName('zbqdyp_zt', row.requestReadyToStart - 0) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`搭建\n体系架构图`" align="center" width="150">
                <template v-slot="{ row }">
                    <div v-if="row.buildArchitecture" :style="`${setStyle(row.buildArchitecture)}`">
                        {{ getDictName('zbqdyp_zt', row.buildArchitecture) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`明确3个以上\n年度核心指标`" align="center" width="170">
                <template v-slot="{ row }">
                    <div v-if="row.defineThreeCoreIndicators" :style="`${setStyle(row.defineThreeCoreIndicators)}`">
                        {{ getDictName('zbqdyp_zt', row.defineThreeCoreIndicators) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`形成\n改革措施清单`" align="center" width="150">
                <template v-slot="{ row }">
                    <div v-if="row.formList" :style="`${setStyle(row.formList)}`">
                        {{ getDictName('zbqdyp_zt', row.formList) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`形成拟出台\n政策文件清单`" align="center" width="150">
                <template v-slot="{ row }">
                    <div v-if="row.issueDocument" :style="`${setStyle(row.issueDocument)}`">
                        {{ getDictName('zbqdyp_zt', row.issueDocument) }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="" :label="`提出调整加快\n实施一批的申请`" align="center" width="150">
                <template v-slot="{ row }">
                    <div v-if="row.requestToStart" :style="`${setStyle(row.requestToStart)}`">
                        {{ getDictName('zbqdyp_zt', row.requestToStart) }}
                    </div>
                </template>
            </el-table-column>
        </el-table>
        <!-- <div class="tips">
            备注：①绿色为已完成事项；②蓝色为推进中事项；③灰色为未启动事项；④白色为暂不涉及事项。
        </div> -->
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView.js'
import utils from '@/utils.js'
import ExcelJS from 'exceljs';
export default {
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            workbook: null,
            projectCategory: ''
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.getData()
        this.$bus.$on('changeDate', (searchDate) => {
            this.getData()
        })
        this.$bus.$on('monthExportExcel', (comp) => {
            if (comp === 'projectBatchMH') {
                this.clickMHExport()
            }
        })
    },
    created() {
        this.$emit('searchDateChange')
    },
    methods: {
        setStyle(value) {
            let style = value < 13
                ? 'background :#38a846;font-weight: bold;'
                : value == 13
                    ? 'background:#00b0f0;font-weight: bold;'
                    : value == 14
                        ? 'background:#e8e8e8;color:#333;font-weight: bold;'
                        : 'background:#a0a0a0;font-weight: bold;'
            style = style + ';margin: 0 auto;'
            return style
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getData() {
            this.loading = true
            let { year, month } = JSON.parse(sessionStorage.getItem('searchDate'))
            apiList.getReadyAndPlanningData({ year, month, type: '3', projectCategory:this.projectCategory }, res => {
                if (res) {
                    let arr = res.map(item => item.orderNo)
                    let index = arr.lastIndexOf(1)
                    this.tableData = res
                    this.$nextTick(() => {
                        let tableRow = this.$refs.myTable.$el.querySelectorAll('.el-table__body tbody .el-table__row')
                        for (let i = 0; i < index; i++) {
                            tableRow[i].style = 'background-color: rgb(5 54 127) !important;'
                        }
                        
                    })

                    this.exportToExcel()
                }
                this.loading = false
            })
        },
        exportToExcel() {
            let columns = [
                { title: '项目名称', dataIndex: 'projectName' },
                { title: '主责单位', dataIndex: 'unitName' },
                { title: '专项小组', dataIndex: 'groupName' },
                { title: '形成\n调研报告', dataIndex: 'produceReport', type: 'value' },
                { title: '形成\n改革方案初稿', dataIndex: "formScheme", type: 'value' },
                { title: '提出调整准备\n启动一批的申请', dataIndex: "requestReadyToStart", type: 'value' },
                { title: '搭建\n体系架构图', dataIndex: "buildArchitecture", type: 'value' },
                { title: '明确3个以上\n年度核心指标', dataIndex: "defineThreeCoreIndicators", type: 'value' },
                { title: '形成\n改革措施清单', dataIndex: "formList", type: 'value' },
                { title: '形成拟出台\n政策文件清单', dataIndex: "issueDocument", type: 'value' },
                { title: '提出调整加快\n实施一批的申请', dataIndex: "requestToStart", type: 'value' }
            ]
            const columnWidths = {
                A: 32,
                B: 13,
                C: 15,
                D: 15,
                E: 18,
                F: 20,
                G: 15,
                H: 18,
                I: 18,
                J: 18,
                K: 20
            }

            const workbook = new ExcelJS.Workbook();
            const worksheet = workbook.addWorksheet('Sheet1');

            const data = JSON.parse(JSON.stringify(this.tableData))

            const headerRow = worksheet.addRow(columns.map(column => column.title));
            headerRow.eachCell((cell) => {
                cell.font = { bold: true, size: 14 };
                cell.alignment = {
                    horizontal: "center",// 水平居中
                    vertical: 'middle', // 垂直居中
                };
                cell.border = {
                    top: { style: 'thin' },
                    left: { style: 'thin' },
                    bottom: { style: 'thin' },
                    right: { style: 'thin' }
                };
                cell.alignment = {
                    wrapText: true,
                    vertical: 'middle',
                    horizontal: 'center'
                }
            });

            data.forEach((rowData) => {
                const newRow = worksheet.addRow(columns.map((column) => {
                    return column.type === 'value' ? utils.getDictName('zbqdyp_zt', rowData[column.dataIndex] - 0) : (rowData[column.dataIndex] || '')
                }));
                newRow.eachCell((cell, rowNum) => {
                    cell.border = {
                        top: { style: 'thin' },
                        left: { style: 'thin' },
                        bottom: { style: 'thin' },
                        right: { style: 'thin' }
                    };
                    cell.alignment = {
                        wrapText: true
                    }
                    if (rowNum > 3) {
                        cell.fill = returnColor(cell.value)
                    }
                    cell.alignment.vertical = 'middle'
                    cell.alignment.horizontal = 'center'
                })
            });
            Object.keys(columnWidths).forEach((columnLetter) => {
                worksheet.getColumn(columnLetter).width = columnWidths[columnLetter];
            });

            function returnColor(value) {
                let argb = value.indexOf('已完成') !== -1
                    ? '38a846'
                    : value.indexOf('推进中') !== -1 ? '00b0f0'
                        : value.indexOf('未启动') !== -1 ? 'e8e8e8'
                            : value.indexOf('未完成') !== -1 ? 'f43308'
                                : value.indexOf('不涉及') !== -1 ? 'a0a0a0' : ''
                return {
                    type: 'pattern',
                    pattern: 'solid',
                    fgColor: { argb }
                }
            }

            this.workbook = workbook
        },
        clickMHExport() {
            this.workbook.xlsx.writeBuffer().then((buffer) => {
                const blob = new Blob([buffer], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' });
                const url = window.URL.createObjectURL(blob);
                const a = document.createElement('a');
                a.href = url;
                a.download = '谋划储备的重大改革项目关键环节和重要事项进度统计表.xlsx';
                a.click();
                window.URL.revokeObjectURL(url);
            });
        }
    },
}
</script>
<style lang="scss" scoped>
/deep/#table-bigger-detail th {
    .cell {
        line-height: 22PX;
    }
}
/deep/.el-table th,
/deep/.el-table td {
    &:nth-child(7) {
        border-right: 6px solid #165696 !important;
    }
}

/deep/#table-bigger-detail .el-table--border th,
/deep/.el-table--border td {
    border-right: 1PX solid rgb(39, 86, 162) !important;
}

/deep/#table-bigger-detail.el-table th.el-table__cell.is-leaf,
/deep/#table-bigger-detail.el-table td.el-table__cell {
    border-bottom: 1PX solid rgb(39, 86, 162) !important;
}

/deep/#table-bigger-detail.dialog_table.el-table {
    thead tr {
        background: none !important;
    }

    thead tr,
    thead tr th {
        background: none !important;
        background-color: #114385 !important;
        color: #FFFFFF;
    }

    th>.cell {
        font-size: 18PX;
        font-family: SimHei;
        font-weight: bold;
        color: #FFFFFF;
    }

    td>.cell {
        color: #FFFFFF !important;
        font-size: 18PX;
        line-height: 140%;

        div {
            padding-top: 10PX;
            padding-bottom: 10PX;
            font-size: 18PX;
        }
    }
}

/deep/#table-bigger-detail.el-table--border {
    border: 1PX solid rgb(39, 86, 162) !important;

    .el-table__cell {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }

    th.el-table__cell {
        border-bottom: 1PX solid rgb(39, 86, 162) !important;
    }

    td {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }

    th {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }
}

/deep/#table-bigger-detail.el-table {
    background-color: transparent;

    tr {
        background-color: rgba(1, 39, 101, 1) !important;
        color: #FFFFFF !important;
    }
}


// #table-bigger-detail .el-table--enable-row-hover .el-table__body tr:hover > td.el-table__cell {
//     background-color: rgba(2, 115, 233, 0.3)!important;
// }
/deep/#table-bigger-detail.el-table tbody tr:hover>td {
    background-color: rgba(2, 115, 233, 0.3) !important;
}

/deep/#table-bigger-detail.el-table--group::after,
/deep/#table-bigger-detail.el-table--border::after,
/deep/#table-bigger-detail.el-table::before {
    background-color: #001f47 !important;
}

/deep/#table-bigger-detail.el-table th.el-table__cell>.cell {
    white-space: pre;

}

/deep/#table-bigger-detail {

    /* 设置滚动条的样式 */
    ::-webkit-scrollbar {
        width: 18px !important; //垂直方向上的宽
        height: 18px !important; //水平方向上的宽
    }

    /* 滚动槽 */
    ::-webkit-scrollbar-track {
        border-radius: 0 !important;
        background-color: #01215a !important;
    }

    /* 滚动条滑块 */
    ::-webkit-scrollbar-thumb {
        border-radius: 12PX;
        background-color: #034eb0 !important;
    }

    /*滚动条交叉样式*/
    ::-webkit-scrollbar-corner {
        background: #01215a !important;
    }
}

.tips {
    font-size: 18PX;
    margin-top: 10px;
}
</style>
<style lang="scss" scoped>
/deep/.el-input__inner {
    color: #fff;
    font-size: 18PX;
    height: 40PX;
    box-sizing: border-box;
    background: transparent;
    border: 1px solid #114385;

    &::placeholder {
        color: #fff;
        font-size: 18PX !important;
    }

    &::-webkit-input-placeholder {
        font-size: 18PX !important;
    }
}
.report-overview {
    height: 100%;
    margin-top: 5PX;

    .search-box {
        height: 40PX;
        line-height: 40PX;
        font-size: 18PX;
        margin-bottom: 10PX;
    }
}

/deep/.dialog_table.el-table {
    th>.cell {
        font-size: 18PX !important;
    }
}
</style>
